@@ -1,7 +1,7 @@
 """Console script for tiff_stack_crop_tool."""
 import argparse
 import sys
-from tiff_stack_crop_tool import crop_all_stacks
+from .tiff_stack_crop_tool import crop_all_stacks
 
 
 def main():
